;; Generated package description from org.el  -*- no-byte-compile: t -*-
(define-package "org" "9.6.3" "Outline-based notes management and organizer" '((emacs "26.1")) :commit "f9bbc79d627299c627cbfdacb565afd05acb0af9" :authors '(("Carsten Dominik" . "carsten.dominik@gmail.com")) :maintainer '("Bastien Guerry" . "bzg@gnu.org") :keywords '("outlines" "hypermedia" "calendar" "wp") :url "https://orgmode.org")
